resolve method
Turn the error into a synthetic success response (e.g. cache hit).
Implementation
void resolve(ResponseContext recovered) => _recovery = recovered;
Turn the error into a synthetic success response (e.g. cache hit).
void resolve(ResponseContext recovered) => _recovery = recovered;