ConnectionException class final
No network connectivity or DNS lookup failed.
- Inheritance
-
- Object
- NetworkException
- ConnectionException
Constructors
- ConnectionException(String message, {Object? cause})
-
const
Properties
- cause → Object?
-
The original exception/error that triggered this, if any.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited