ErrorHandler class

Thin wrapper passed to Interceptor.onError.

Constructors

ErrorHandler(NetworkException _error)

Properties

error NetworkException
no setter
hashCode int
The hash code for this object.
no setterinherited
recovery ResponseContext?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next(NetworkException err) → void
Propagate (possibly replaced) error further.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(ResponseContext recovered) → void
Turn the error into a synthetic success response (e.g. cache hit).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited