RequestHandler class
Thin wrapper passed to Interceptor.onRequest so the interceptor can either mutate & proceed or short-circuit with a synthetic result.
Constructors
- RequestHandler(RequestContext _context)
Properties
- context → RequestContext
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRejected → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortCircuit ↔ NetworkException?
-
If non-null after
onRequestreturns, the chain is short-circuited.getter/setter pair
Methods
-
next(
RequestContext ctx) → void - Update the request (e.g. inject auth header) and let it continue.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reject(
NetworkException error) → void - Abort the chain with an error — no HTTP request is made.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited