ResponseHandler class

Thin wrapper passed to Interceptor.onResponse.

Constructors

ResponseHandler(ResponseContext _context)

Properties

context ResponseContext
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortCircuit NetworkException?
getter/setter pair

Methods

next(ResponseContext ctx) → void
Let the (possibly mutated) response continue down the chain.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reject(NetworkException error) → void
Turns a response into an error (e.g. envelope-level error codes).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited