NetworkTransferClient class abstract
Dedicated abstraction for large file operations. Keeps the core NetworkClient from becoming a God Object.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
download(
String url, {required String savePath, ProgressCallback? onProgress, RequestOptions? options}) → Future< Result< File> > - Standard one-shot file download.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upload<
T> (String path, {required List< UploadFile> files, Map<String, String> ? fields, JsonParser<T> ? parser, ProgressCallback? onProgress, RequestOptions? options}) → Future<Result< T> > - Handles large multipart file uploads with progress tracking.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited