HttpStatusException class final

Server responded, but with a non-2xx status code.

Inheritance

Constructors

HttpStatusException({required int statusCode, required String message, String? responseBody, Object? cause})
const

Properties

cause Object?
The original exception/error that triggered this, if any.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description.
finalinherited
responseBody String?
Raw response body (may be null if the server sent no body).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited